package Moped::Msg;

our (@ISA, $VERSION);
require DynaLoader;
@ISA = qw(DynaLoader);
$VERSION = '0.01';
 Moped::Msg->bootstrap();
1;

